<?php

declare(strict_types=1);

namespace CKPL\Pay\Definition\Payment;

use CKPL\Pay\Definition\Amount\AmountInterface;

/**
 * Class Payment.
 *
 * @package CKPL\Pay\Definition\Payment
 */
class Payment implements PaymentInterface
{
    /**
     * @var string|null
     */
    protected $externalPaymentId;

    /**
     * @var AmountInterface|null
     */
    protected $amount;

    /**
     * @var string|null
     */
    protected $description;

    /**
     * @var bool|null
     */
    protected $allowPayLater;

    /**
     * @var string|null
     */
    protected $returnUrl;

    /**
     * @var string|null
     */
    protected $errorUrl;

    /**
     * @var string|null
     */
    protected $notificationUrl;

    /**
     * @var string|null
     */
    protected $integrationPlatform;

    /**
     * @var string|null
     */
    protected $acceptLanguage;

    /**
     * @var mixed|string|null
     */
    protected $notificationUrlParameters;

    /**
     * @return string|null
     */
    public function getExternalPaymentId(): ?string
    {
        return $this->externalPaymentId;
    }

    /**
     * @param string $externalPaymentId
     *
     * @return Payment
     */
    public function setExternalPaymentId(string $externalPaymentId): void
    {
        $this->externalPaymentId = $externalPaymentId;
    }

    /**
     * @return AmountInterface|null
     */
    public function getAmount(): ?AmountInterface
    {
        return $this->amount;
    }

    /**
     * @param AmountInterface $amount
     *
     * @return Payment
     */
    public function setAmount(AmountInterface $amount): void
    {
        $this->amount = $amount;
    }

    /**
     * @return string|null
     */
    public function getDescription(): ?string
    {
        return $this->description;
    }

    /**
     * @param string $description
     *
     * @return Payment
     */
    public function setDescription(?string $description): void
    {
        $this->description = $description;
    }

    /**
     * @return bool|null
     */
    public function getAllowPayLater(): ?bool
    {
        return $this->allowPayLater;
    }

    /**
     * @param bool $allowPayLater
     *
     * @return Payment
     */
    public function setAllowPayLater(bool $allowPayLater): void
    {
        $this->allowPayLater = $allowPayLater;
    }

    /**
     * @return string|null
     */
    public function getReturnUrl(): ?string
    {
        return $this->returnUrl;
    }

    /**
     * @param string|null $returnUrl
     *
     * @return Payment
     */
    public function setReturnUrl(?string $returnUrl): void
    {
        $this->returnUrl = $returnUrl;
    }

    /**
     * @return string|null
     */
    public function getErrorUrl(): ?string
    {
        return $this->errorUrl;
    }

    /**
     * @param string|null $errorUrl
     *
     * @return Payment
     */
    public function setErrorUrl(?string $errorUrl): void
    {
        $this->errorUrl = $errorUrl;
    }

    /**
     * @return string|null
     */
    public function getNotificationUrl(): ?string
    {
        return $this->notificationUrl;
    }

    /**
     * @param string|null $notificationUrl
     *
     * @return Payment
     */
    public function setNotificationUrl(?string $notificationUrl): void
    {
        $this->notificationUrl = $notificationUrl;
    }

    /**
     * @return string|null
     */
    public function getIntegrationPlatform(): string
    {
        return $this->integrationPlatform;
    }

    /**
     * @param string|null $integrationPlatform
     */
    public function setIntegrationPlatform(?string $integrationPlatform): void
    {
        $this->integrationPlatform = $integrationPlatform;
    }

    /**
     * @return string|null
     */
    public function getAcceptLanguage(): ?string
    {
        return $this->acceptLanguage;
    }

    /**
     * @param string|null $acceptLanguage
     */
    public function setAcceptLanguage(?string $acceptLanguage): void
    {
        $this->acceptLanguage = $acceptLanguage;
    }

    /**
     * @return mixed|string|null
     */
    public function getNotificationUrlParameters()
    {
        return $this->notificationUrlParameters;
    }

    /**
     * @param mixed $notificationUrlParameters
     */
    public function setNotificationUrlParameters($notificationUrlParameters): void
    {
        $this->notificationUrlParameters = $notificationUrlParameters;
    }
}
